@@ -208,6 +208,15 @@ class OSGiCleanMapper {
         return registrations.get(alias);
     }
 
+    /**
+     * Looks up {@link HttpHandler}s.
+     *
+     * @return The unmodifiable {@link HttpHandler}s.
+     */
+    Set<Entry<String, HttpHandler>> getHttpHandlers() {
+        return Collections.unmodifiableSet(registrations.entrySet());
+    }
+
     /**
      * Remove registration information for internal book keeping.
      *
