@@ -93,9 +93,11 @@ package com.openexchange.http.grizzly.service.http;
 
 import java.io.IOException;
 import java.io.PrintWriter;
+import java.util.Collection;
 import java.util.Enumeration;
 import java.util.EventListener;
 import java.util.HashMap;
+import java.util.LinkedList;
 import java.util.List;
 import java.util.Map;
 import java.util.concurrent.CopyOnWriteArrayList;
@@ -143,7 +145,7 @@ public class OSGiServletHandler extends ServletHandler implements OSGiHandler {
 
     private String servletPath;
 
-    private CopyOnWriteArrayList<Filter> servletFilters;
+    private volatile CopyOnWriteArrayList<Filter> servletFilters;
 
     private FilterChainFactory filterChainFactory;
 
@@ -245,6 +247,41 @@ public class OSGiServletHandler extends ServletHandler implements OSGiHandler {
         }
     }
 
+    /**
+     * Updates the chain of Filters this ServletHandler manages.
+     *
+     * @param filtersToRemove The filters to remove
+     * @param filtersToRemove The filters to add
+     */
+    protected void updateFilters(final Collection<Filter> filtersToRemove, final Collection<Filter> filtersToAdd) {
+        try {
+            List<Filter> list = new LinkedList<Filter>(servletFilters);
+            list.removeAll(filtersToRemove);
+
+            for (Filter filter : filtersToAdd) {
+                filter.init(createFilterConfig(getServletCtx(), filter.getClass().getName(), null));
+                list.add(filter);
+            }
+
+            servletFilters = new CopyOnWriteArrayList<Filter>(list);
+        } catch (Exception e) {
+            LOG.error(e.toString(), e);
+        }
+    }
+
+    /**
+     * Removes a filter from the chain of Filters this ServletHandler manages.
+     *
+     * @param filter Instance of the Filter to remove
+     */
+    protected void removeFilter(final Filter filter) {
+        try {
+            servletFilters.remove(filter);
+        } catch (Exception e) {
+            LOG.error(e.toString(), e);
+        }
+    }
+
     // @Override
     // protected void setPathData(Request from, HttpServletRequestImpl to) {
     // to.setServletPath(getServletPath());
@@ -430,7 +467,12 @@ public class OSGiServletHandler extends ServletHandler implements OSGiHandler {
                         handleThrowable(e, request, response);
                     }
                 }
-            } catch (final Throwable throwable) {
+            } catch (IOException ioe) {
+                if (response instanceof HttpServletResponse) {
+                    // 500 - Internal Server Error
+                    ((HttpServletResponse) response).setStatus(500);
+                }
+            } catch (Throwable throwable) {
                 handleThrowable(throwable, request, response);
             }
 
@@ -459,7 +501,7 @@ public class OSGiServletHandler extends ServletHandler implements OSGiHandler {
         private void handleThrowable(Throwable throwable, ServletRequest request, ServletResponse response) {
             ExceptionUtils.handleThrowable(throwable);
 
-            StringBuilder logBuilder = new StringBuilder(128).append("Error processing request:\n");
+            StringBuilder logBuilder = new StringBuilder(128).append("Error processing request:").append(System.getProperty("line.separator"));
             logBuilder.append(LogProperties.getAndPrettyPrint(LogProperties.Name.SESSION_SESSION));
 
             if (request instanceof HttpServletRequest && response instanceof HttpServletResponse) {
@@ -554,6 +596,7 @@ public class OSGiServletHandler extends ServletHandler implements OSGiHandler {
                     try {
                         ((ServletRequestListener) listeners[i]).requestDestroyed(event);
                     } catch (Throwable t) {
+                        ExceptionUtils.handleThrowable(t);
                         if (LOGGER.isLoggable(Level.WARNING)) {
                             LOGGER.log(Level.WARNING, LogMessages.WARNING_GRIZZLY_HTTP_SERVLET_CONTAINER_OBJECT_DESTROYED_ERROR(
                                 "requestDestroyed",
@@ -573,6 +616,7 @@ public class OSGiServletHandler extends ServletHandler implements OSGiHandler {
                     try {
                         ((ServletRequestListener) listeners[i]).requestDestroyed(event);
                     } catch (Throwable t) {
+                        ExceptionUtils.handleThrowable(t);
                         if (LOGGER.isLoggable(Level.WARNING)) {
                             LOGGER.log(Level.WARNING, LogMessages.WARNING_GRIZZLY_HTTP_SERVLET_CONTAINER_OBJECT_INITIALIZED_ERROR(
                                 "requestDestroyed",
