@@ -59,7 +59,6 @@ import java.util.concurrent.TimeUnit;
 import javax.servlet.http.HttpServletRequest;
 import org.apache.commons.codec.binary.Base64;
 import org.apache.commons.collections.CollectionUtils;
-import org.apache.commons.collections.Transformer;
 import org.glassfish.grizzly.http.server.Request;
 import org.slf4j.Logger;
 import com.google.common.cache.Cache;
@@ -81,8 +80,6 @@ public final class RequestTools {
 
     private static final Logger LOG = org.slf4j.LoggerFactory.getLogger(RequestTools.class);
 
-    private static final Transformer LOWER_CASER = new StringToLowerCaseTransformer();
-
     /**
      * Initializes a new {@link RequestTools}.
      */
